## Function and Dynamics

Invariant patterns exist on all scalar levels, from the bouncing of
molecules, to genomics, to more intuitive graphical symmetries (as
previously presented in branching patterns). This segment will show that
functional invariants can be explained via dynamical systems theory.
Before going any further into the field a few concepts have to be
defined.

### Box:Definitions 

A ***dynamical system*** is a set of possible states which change over
time, with certain parameters and rules. The initial state can exist for
a certain amount of time, known as phase, until it qualitatively
changes, known as phase transitions. Any state of the dynamic system
within a region (basin of attraction) will ultimately tend toward a
specific state or set of states (attractors), making it deterministic. 

***Complex systems*** are systems in which a large number of simple
entities interact to form complex behavior, which is not achievable by
the single entity. Ants, slime mold, tissue, neural networks have all
been modelled as complex systems. An example of the behavior of complex
systems is given by the complex patterns generated by the simple rules
in cellular automata (see Wolfram, S. 1985). Depending on the
sophistication of the system one can speak of different gradients of
complexity. Complex systems can be non-linear, chaotic and/or adaptive.

In biology, dynamical systems have ***nonlinearity*** meaning that their
output is not directly proportional to their input. In mathematical
models of complex behavior, non linearities can represent contextual
dependencies, history or saturations. The output-to-input ratio depends
on the strength on the input. Non-linear functions cannot be written as
linear equations and tend to present polynomials of degree larger than
one. An example of non-linearity in responses, is the frequency of
action potentials firing in neurons, that at a low input fire once but
that fire repeatedly at a higher input. This periodic production of
action potentials can be reached once a *critical* point is reached, at
a phase transition, in this example, related to input strength.

A ***chaotic system*** is a non-linear dynamic system that is sensitive
dependent on the initial conditions, where even seemingly negligible
changes in the initial conditions can lead to largely divergent
outcomes, essentially unpredictable/’chaotic’. Fractals are a sub-form
of chaotic systems, which tend towards ’infinite’ recursion.|

A ***complex adaptive system*** is a complex system which emerges when
the system is able to learn and adapt to itself (experience attained
across time) and its environment. Though a double pendulum is a a
complex system it does not seem to be able to learn from experience like
a swarm of insects or a developing human cell which constantly adapts to
its environment.

\* There exist stochastic dynamical systems as well, modelled which
model unpredictable dynamical behavior by adding some noise (through a
random number generator). But ultimately this noise usually represents
some unaccounted influence, or measurement limitation, rather then
represent true unpredictability.|

Mathematically, a dynamical system is an equation (or several) which
represent how some variable *x* changes over time. This variable can
evolve into different phases but ultimately will tend toward a preferred
state *y,* known as an attractor, for example a moving pendulum will
slow down across time and reach its equilibrium position at the bottom,
unless fed with energy to maintain its oscillations. Independent of the
initial value, and what phases *x* will go through, the system will
converge over time to the state/points it is attracted to therefore
known as attractors (though an oscillatory state of a non-dissipative
can also be an attractor, called a limit cycle attractor). In biological
systems there is a thermal non-equilibrium, many life processes being
exothermal, creating entropy, i.e. for a complex biological system to
maintain itself and its ordered structure/constancy in an ever-changing
environment, any biological organism obtains and releases energy with
its environment, creating more chaotic disorder around it, to maintain
its own order. Next to dissipating heat, complex structures (animate &
inanimate) are often *non-linear* dynamic systems, meaning that they
break symmetry and behave chaotically (Alligood, Chaos), where a minor
change in the input/initial stage of the aforementioned variable *x* can
have radical different effects on the phases/output and final attractor
state. This makes living systems appear having random behavior though
below that chaos there is order. Because self-organized dynamical
systems are context-dependent (of for e.g the initial phase, the
attractors, and their environment) and functionally specific, as a whole
meaningful patterns arise. Chaos in nonlinear dynamic systems can be
identified as aperiodic, seemingly unpredictable behavior in a
deterministic system, which is sensitively dependent on the initial
state/conditions, where small changes in the initial conditions get
amplified vastly making it seem random (Lorenz).

### Hodgkin-Huxley: Neuron models as dynamical systems
A perfect example of a neural non-linear dynamical system is the
Hodgkin-Huxley model of the action potential in nerve cells (Hodgkin &
Huxley). The Hodgkin-Huxley model is a set of equations that were
initially taken to represent the functioning of the action potential in
the squid giant axons. By simplifying it to only a few elements that
included using membrane potential as state variable, electrical input
current as main parameter, in conjunction with voltage dependent
potassium and sodium channels, this model was able to represent how
action potentials across all neural species, almost universally, most
likely due to an evolutionary common origin (Negrello, IoB, pg. 104).
One can apply the bifurcation theory from dynamical systems theory to
the Hodgkin-Huxley Model, to understand ‘how an action potential is
initiated, maintained and terminated’ (Negrello, IoB, pg. 107). The
lipid bilayer of the cell membrane is interpreted as an electrical
current modulated by the ion channels. More precisely the voltage-gated
ion channels are said to function non-linearily. If the initial current
received by the neuron increases, then the amount of action potentials
also increase – but only if there is a local minimum voltage level (as
explained by the dynamical Hopf bifurcation).

### Neural Networks and Learning
However, the brain is not only dynamic it is also complex due to the
vast amount of neurons, neuronal firing, and molecular exchange
happening every moment. Hebb’s invariant rule for neurons is that a
connected neuron that repeatedly fires with another will show metabolic
growth. Synaptic strength between neurons is thus increased depending on
how much they jointly fire, allowing for self-organization in nervous
systems. Neural networks like the Hopfield network, though artificial,
present a possibility for how neurons can store and retrieve information
patterns by dynamically exciting each other applying Hebbian learning.
Reinforced connections, like in Hebb’s rule, enable learning in
networks. In a Hopfield network all artificial neurons are connected
with another. When a certain firing pattern is stored (with a minimum of
energy) and a new similar pattern is presented (that is certain nodes
have the same firing pattern), after a set amount of synchronous or
asynchronous firing of the nodes, the network will find the learnt
network (unless it settles for a so called spurious local minimum, which
is a pattern similar to the stored one but not the same). The inserted
similar pattern will tend towards basins of attractions, one of them
being the previously stored pattern.
