### Constancy and Variability in Neural Systems

Neural systems present immense variability across all physical scales,
from the nano to macrolevels, and across all temporal planes, from
processes taking nanoseconds to those happening across a lifespan, or
across lifespans as in evolution. But still, given a describable
phenomenon and sufficient data, we are able to identify (meta)stable
patterns that co-occur with the phenomenon, so called invariants, which
often follow a statistical norm and can account for deviations of an
invariant average (e.g. average EEG waves can show abnormal spikes).
“Variability and constancy are present in substrate (what it is made of
–material cause), structure (how it is organized – formal cause), and
function (what it is for – final cause)” (Negrello, 2009, p.3). Though
some sources of variability are often intelligible with respect to some
invariant response, the consequences of either are often incalculable.
For example, despite stochastic variability in the activation of ion
channels, neurons produce an invariant cellular response, the spike.
Though a causal link is in principle established by the production of a
spike that activates a synapse, the consequence of a single spike to the
overall functioning of the central nervous system (CNS) and of the
organism as a whole, such as movement, cognition and consciousness
(invariants of behaviour), often seems mindboggling. Extrapolating these
sources of variability to the vast amount of neurons present in a human
brain, estimated at around 96 billion (Azevedo et al. 2009), one can
confidently state that neural systems present an immense amount of
variability and complexity. Nevertheless, rather than shrug in despair,
science diligently hypothesizes about which variability has measurable
consequences to the whole organism. This is feasible only when there are
experiments that can isolate/manipulate sources of variability from
constancy. Science attempts to point to the variability that matters,
and when it does not. Just like in dice throwing games, where any number
can be equally thrown, such variability allows for a uniform probability
distribution, yet certain values can have a more functional meaning for
the game than others (e.g. Throwing 6 in Mensch Aergere dich nicht).\
In order to understand the problem of how multifaceted organismic
function (e.g. behavior) is organized from neural complexity and
variability, one must commit to the fact that biology is different from
physics, though it is clearly based/supervenient on physics. The
difference lies in biology presenting purposeful behaviour. Yet in
physics applying reductionism has been very successful. Reductionism is
the idea that understanding the properties of the elements of a system
leads to an understanding of the whole system, but it falls short in the
explanation of biological function. To understand why this is the case
we turn to complex systems, in which a collection of stereotypical
elements interacting in simple ways can lead to radically different
properties. Phase transitions offer new potentialities (in Aristotle’s
sense) of interaction between systems.

### Function is ineluctable in the description of organized behavior

Both in classical physics as in biology one can study potential and
actual states across time, however, causality works differently in
biology. Most basic sciences measure properties of a system with the
presumption that by reducing the problem to bare essentials, the higher
level properties become trivial consequences of the basic properties.
Though in many cases scientific reductionism has allowed for major
advances, it is unyielding to try to explain complex organic systems as
typical machinery following mechanistic causality. This is because in
biology seemingly purposeful behavior appears, where the probability of
predicting the causal outcome is lower than in regular physics (Mayr,
1961). Though on the biomolecular level causal predictions may in
certain conditions and in highly controlled experimental paradigms have
a high level of accuracy, in most natural scenarios causal prediction
becomes difficult due to less predictable factors such as history
dependence and long-term evolution; random genetic mutations; unique
biological features; dynamic complexity; and the emergence of new
biological features when several biological components integrate (Mayr,
1961). This unpredictability does not eschew causality, but can be best
explained by several sets of causes, many of which are only intelligible
at the level of the organism itself and, most often, by teleological
causality. In teleogical causality, the resulting final causal effect is
a telos or goal, which motivates the initial cause. In biology there is
a telos or “*end* for the sake of which they exist - the possible state
of things that they bring closer to existing - that characterizes them”
(Deacon, T.W., 2009, p.24).That is, a biological system is not merely
pushed like a ball, but can also move purposefully towards something.
~~In other words, the potential end result (moving from *A* to *B*, or
obtaining energy) can initiate the primary causes in a recursive
manner.~~ One has not to recur into analogies of a little man in our
brain (homunculus), or beliefs in vitalism to understand this.
Teleological causality simply builds on mechanistic causality, and can
arise under certain conditions in complex living systems (Sherman &
Deacon, 2007), which can be acounted for by our immense neural
variability.

In biology, many functional, end-directed behaviors, have a solid
empirical basis. A lot of research on the behavior of organisms departs,
implicitly or explicitly, on the assumption of function. Most behavioral
neuroscience assumes a functional behavior and searches for the neural
structures that may explain it. Recent breakthroughs have linked brain
structure to a behavioral function through invariant patterns, such as
hippocampal place cells and entorhinal grid cells, which emerge from
particular neural networks and are linked to the ability of animals to
navigate their environments. Place cells fire complex bursts when an
animal moves through a specific location (O’Keefe and Dostrovsky, 1971;
for complex EEG spikes see James Ranck, 1973). On the contrast, grid
cells’ periodical firing can be qualitatively mapped with the
spatiotemporal trajectory an animal is taking, i.e. there are patterns
that relate experience through neural activity. Place cells (fire when
an animal crosses a specific place field), grid cells (fire when animal
passes through firing fields which have a proportional triangular
distance from another) and boundary cells (fire when an animal
recognizes a boundary in its environment) form a visuospatial cognitive
map in the hippocampus based on neural path integration (Barry et al.
2006) (McNaughton, Battaglia, Jenson, Moser & Moser, 2006). So there is
good reason to consider that it is a necessary corollary ~~of the
organization~~ of the behavioral function to co-arise with the presence
of such cells: once there is a stream of experience for the organism,
with the constraints given by body and environment, there is a
changeable neural structure that already subserves the behavior in an
gradual evolutionary path, then place and grid cells emerge. And once
that kind of pattern of neural activity emerges in a dynamical context
in the brain, then, potentially, other neural functions can share that
substrate, that activity. In rodents place and grid cells have shown to
fire with a correlated stream of theta oscillations (4 to 11 Hz)
(Burgess & O’Keefe, 2011; Koenig et al., 2011). Yet some evidence also
points that in bats’ enthorinal grid and hippocampal place cells can
fire without regular theta oscillations (Yartsev, Witter & Ulankonvsky,
2011; Ulankovsky & Moss, 2007), possibly utilizing an additional neural
substrate and echolocation to achieve the same behavior (locating
oneself) and functionality of grid and place cells. Thus theta
oscillation probably allows for more prominent and stable place and grid
cell firing (Buzsáki & Moser, 2013) which can be modelled dynamically
and as oscillatory neural networks (Shilnikov & Maurer, 2016). When
constructing a functional hypothesis as when measuring place cells we
have a mixture of serendipity (electrodes measuring activity in the
hippocampus whilst the mouse is moving around) plus having a reliable
form of brain measurement. But crucially, in order to explain the
behavior, experimenters assume that the goal oriented behavior exists.
Though place and grid cells give us an insight how specific cellular
activity can correlate with a purposeful effect on behavioral functions,
these correlations do not exist if the behavior is excluded from the
picture. This means that the properties found in place, grid, and
boundary cells are not necessarily the only or main properties with
which these cells correlate, nor are they necessarily the only cells
involved in spatial movement and its memorization, nor indeed, that
spatial movement and memorization are the best ways to describe the
behavior. Place and grid cells do bridge gaps between two scales
(cellular vs. behavioral) and show how function plays a decisive role on
the interpretation of activity, but the bridge is built by the
scientist. Another example on a lower level is how neurochemistry is
linked to modulation, where the the acitivity of ion channels can affect
more higher-level functional states (e.g. a human being fearful or
hungry). Ion channels, place cells and grid cells cannot account for why
entire neural systems provide end-directed, meaningful behavior (like
movement, thoughts or speech). However, they do elucidate how *we must
assume function to study mechanism*, to fully understand functional
behavior in organisms in a context-dependent environment. The assumption
of teleology/function in the brain enables measurement of dynamical
patterns.

When deconstructing the model of the neural system one can create a
simple model: